
#include "types.h"
#include <stdio.h>

FILE *file = stdin ;

char record [MAX_STR_SIZE] ;

int pnt_size ;


void get_axs_layout (axs_layout)
AXS_LAYOUT *axs_layout ;
{
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%f %f", &(axs_layout->maj_wid), &(axs_layout->min_wid))
      != 2)
  {
    fprintf (stderr, "ERROR: expecting gradation widths\n") ;
    exit (0) ;
  }
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%f %f %d", 
    &(axs_layout->num_dsp.x), &(axs_layout->num_dsp.y),
    &(axs_layout->num_siz))
      != 3)
  {
    fprintf (stderr, "ERROR: expecting axis numbering layout\n") ;
    exit (0) ;
  }
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%f %f %d", 
    &(axs_layout->lab_dsp.x), &(axs_layout->lab_dsp.y),
    &(axs_layout->lab_siz))
      != 3)
  {
    fprintf (stderr, "ERROR: expecting axis label layout\n") ;
    exit (0) ;
  }
}

void get_layout (layout)
LAYOUT *layout ;
{
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%f %f %f %f",
    &(layout->bl_pos.x), &(layout->bl_pos.y),
    &(layout->tr_pos.x), &(layout->tr_pos.y))
      != 4)
  {
    fprintf (stderr, "ERROR: expecting box extent\n") ;
    exit (0) ;
  }
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%f %f %d", 
    &(layout->title_pos.x), &(layout->title_pos.y),
    &(layout->title_siz))
      != 3)
  {
    fprintf (stderr, "ERROR: expecting title layout\n") ;
    exit (0) ;
  }
  get_axs_layout (&(layout->x_lay)) ;
  get_axs_layout (&(layout->y_lay)) ;
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%f", &(layout->pnt_wid))  != 1)
  {
    fprintf (stderr, "ERROR: expecting point width\n") ;
    exit (0) ;
  }
}

get_title (title)
char *title ;
{
  fgets (title, MAX_STR_SIZE, file) ;
  title [strlen (title) - 1] = '\0' ;    /* strip newline */
}

get_axis  (axis)
AXS_RANGE *axis ;
{
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%f %f", &(axis->min), &(axis->max))
      != 2)
  {
    fprintf (stderr, "ERROR: expecting axis limits\n") ;
    exit (0) ;
  }
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%f %f", &(axis->anch), &(axis->intv))
      != 2)
  {
    fprintf (stderr, "ERROR: expecting axis numbering scheme\n") ;
    exit (0) ;
  }
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%d", &(axis->subd))  != 1)
  {
    fprintf (stderr, "ERROR: expecting axis number of subdivisions\n") ;
    exit (0) ;
  }
  if (!*fgets (axis->fmt, MAX_STR_SIZE, file))
  {
    fprintf (stderr, "ERROR: expecting axis number format\n") ;
    exit (0) ;
  }
  axis->fmt [strlen (axis->fmt) - 1] = '\0' ;    /* strip newline */
  if (!*fgets (axis->lab, MAX_STR_SIZE, file))
  {
    fprintf (stderr, "ERROR: expecting axis label\n") ;
    exit (0) ;
  }
  axis->lab [strlen (axis->lab) - 1] = '\0' ;    /* strip newline */
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%d", &(axis->dup))  != 1)
  {
    fprintf (stderr, "ERROR: expecting axis duplication flag\n") ;
    exit (0) ;
  }
}

int get_data_header (data_header)
DAT_HDR *data_header ;
{
  int count ;

  fgets (record, MAX_STR_SIZE, file) ;
  if ((count = sscanf (record, "%d", &(data_header->pnt_fmt))) == EOF)
    return 0 ;
  else
    if (count != 1)
    {
      fprintf (stderr, "ERROR: expecting point type\n") ;
      exit (0) ;
    }
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%d", &(data_header->spl))  != 1)
  {
    fprintf (stderr, "ERROR: expecting spline flag\n") ;
    exit (0) ;
  }
  fgets (record, MAX_STR_SIZE, file) ;
  if (sscanf (record, "%d %d",
    &(data_header->err_x), &(data_header->err_y))
      != 2)
  {
    fprintf (stderr, "ERROR: expecting error bar flags\n") ;
    exit (0) ;
  }
  fgets (record, MAX_STR_SIZE, file) ;
  if ((count = sscanf (record, "%d %f %f",
    &(data_header->imp), &(data_header->form.m), &(data_header->form.c)))
      < 1)
  {
    fprintf (stderr, "ERROR: expecting implicit abscissae flag\n") ;
    exit (0) ;
  }
  else
    if (data_header->imp && (count != 3))
    {
      fprintf (stderr, "ERROR: expecting implicit abscissae formula\n") ;
      exit (0) ;
    }

  /* Set 'pnt_size', for use by 'get_point' */

  pnt_size = 2 ;
  if (data_header->err_x) pnt_size ++ ;
  if (data_header->err_y) pnt_size ++ ;
  if (data_header->imp)   pnt_size -- ;

  return 1 ;
}

int get_point (data_point)
float *data_point  ;
{
  int count ;

  fgets (record, MAX_STR_SIZE, file) ;
  if ((count = sscanf (record, "%f %f %f %f",
      data_point, data_point + 1, data_point + 2, data_point + 3))
      == EOF)
    return (0) ;
  else
    if (count != pnt_size)
    {
      fprintf (stderr, "ERROR: expecting %d numbers in data point\n",
	       pnt_size) ;
      exit (0) ;
    }
  return 1 ;
}
